==> bval-parent-0.5-source-release.zip: bval-parent-0.5/bval-extras/src/main/java/org/apache/bval/extras/constraints/net/InetAddressValidator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.bval.extras.constraints.net;

import java.util.regex.Pattern;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

/**
 * <p><b>InetAddress</b> validation and conversion routines (<code>java.net.InetAddress</code>).</p>
 *
 * <p>This class provides methods to validate a candidate IP address.
 */
public class InetAddressValidator implements ConstraintValidator<InetAddress, String> {

    private static final Pattern IPV4_PATTERN = Pattern.compile("^([01]?\\d\\d?|2[0-4]\\d|25[0-5])\\."
                                                                + "([01]?\\d\\d?|2[0-4]\\d|25[0-5])\\."
                                                                + "([01]?\\d\\d?|2[0-4]\\d|25[0-5])\\."
                                                                + "([01]?\\d\\d?|2[0-4]\\d|25[0-5])$");

    /**
     * {@inheritDoc}
     */
    public boolean isValid(String value, ConstraintValidatorContext context) {
        if (!IPV4_PATTERN.matcher(value).matches()) {
            return false;
        }

        return true;
    }

    /**
     * {@inheritDoc}
     */
    public void initialize(InetAddress parameters) {
        // do nothing (as long as InetAddress has no properties)
    }

}

==> bval-parent-2.0.6-source-release.zip: bval-parent-2.0.6/bval-extras/src/main/java/org/apache/bval/extras/constraints/net/InetAddressValidator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.bval.extras.constraints.net;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;
import java.util.regex.Pattern;

/**
 * <p><b>InetAddress</b> validation and conversion routines (<code>java.net.InetAddress</code>).</p>
 *
 * <p>This class provides methods to validate a candidate IP address.
 */
public class InetAddressValidator implements ConstraintValidator<InetAddress, CharSequence> {

    private static final Pattern IPV4_PATTERN =
        Pattern.compile("^([01]?\\d\\d?|2[0-4]\\d|25[0-5])\\." + "([01]?\\d\\d?|2[0-4]\\d|25[0-5])\\."
            + "([01]?\\d\\d?|2[0-4]\\d|25[0-5])\\." + "([01]?\\d\\d?|2[0-4]\\d|25[0-5])$");

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean isValid(CharSequence value, ConstraintValidatorContext context) {
        if (!IPV4_PATTERN.matcher(value).matches()) {
            return false;
        }

        return true;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void initialize(InetAddress parameters) {
        // do nothing (as long as InetAddress has no properties)
    }

}
